@@ -33,15 +33,14 @@
 #include "ui_kpassworddialog.h"
 
 /** @internal */
-class KPasswordDialog::KPasswordDialogPrivate
+class Q_DECL_HIDDEN KPasswordDialog::KPasswordDialogPrivate
 {
 public:
     KPasswordDialogPrivate(KPasswordDialog *q)
         : q(q),
-          userEditCombo(0),
-          pixmapLabel(0),
-          commentRow(0),
-          isToggleEchoModeAvailable(true)
+          userEditCombo(nullptr),
+          pixmapLabel(nullptr),
+          commentRow(0)
     {}
 
     void actuallyAccept();
@@ -50,9 +49,6 @@ public:
     void updateFields();
     void init();
 
-    void toggleEchoMode();
-    void showToggleEchoModeAction(const QString &text);
-
     KPasswordDialog *q;
     Ui_KPasswordDialog ui;
     QMap<QString, QString> knownLogins;
@@ -60,8 +56,6 @@ public:
     QLabel *pixmapLabel;
     KPasswordDialogFlags m_flags;
     unsigned int commentRow;
-    QAction *toggleEchoModeAction;
-    bool isToggleEchoModeAvailable;
 };
 
 KPasswordDialog::KPasswordDialog(QWidget *parent,
@@ -125,13 +119,6 @@ void KPasswordDialog::KPasswordDialogPrivate::init()
 
     updateFields();
 
-    QIcon visibilityIcon = QIcon::fromTheme(QStringLiteral("visibility"), QIcon(QStringLiteral(":/icons/visibility.svg")));
-    toggleEchoModeAction = ui.passEdit->addAction(visibilityIcon, QLineEdit::TrailingPosition);
-    toggleEchoModeAction->setVisible(false);
-    toggleEchoModeAction->setToolTip(tr("Change the visibility of the password"));
-    connect(toggleEchoModeAction, SIGNAL(triggered(bool)), q, SLOT(toggleEchoMode()));
-    connect(ui.passEdit, SIGNAL(textChanged(QString)), q, SLOT(showToggleEchoModeAction(QString)));
-
     QRect desktop = QApplication::desktop()->screenGeometry(q->topLevelWidget());
     q->setMinimumWidth(qMin(1000, qMax(q->sizeHint().width(), desktop.width() / 4)));
     QStyleOption option;
@@ -140,23 +127,6 @@ void KPasswordDialog::KPasswordDialogPrivate::init()
     q->setPixmap(QIcon::fromTheme(QStringLiteral("dialog-password")).pixmap(iconSize));
 }
 
-void KPasswordDialog::KPasswordDialogPrivate::toggleEchoMode()
-{
-    if (ui.passEdit->echoMode() == QLineEdit::Password) {
-        ui.passEdit->setEchoMode(QLineEdit::Normal);
-        toggleEchoModeAction->setIcon(QIcon::fromTheme(QStringLiteral("hint"), QIcon(QStringLiteral(":/icons/hint.svg"))));
-    }
-    else if (ui.passEdit->echoMode() == QLineEdit::Normal) {
-        ui.passEdit->setEchoMode(QLineEdit::Password);
-        toggleEchoModeAction->setIcon(QIcon::fromTheme(QStringLiteral("visibility"), QIcon(QStringLiteral(":/icons/visibility.svg"))));
-    }
-}
-
-void KPasswordDialog::KPasswordDialogPrivate::showToggleEchoModeAction(const QString &text)
-{
-    toggleEchoModeAction->setVisible(isToggleEchoModeAvailable && !text.isEmpty());
-}
-
 void KPasswordDialog::setPixmap(const QPixmap &pixmap)
 {
     if (!d->pixmapLabel) {
@@ -197,7 +167,7 @@ QString KPasswordDialog::username() const
 
 QString KPasswordDialog::password() const
 {
-    return d->ui.passEdit->text();
+    return d->ui.passEdit->password();
 }
 
 void KPasswordDialog::setDomain(const QString &domain)
@@ -248,7 +218,7 @@ void KPasswordDialog::addCommentLine(const QString &label,
     int spacing = d->ui.formLayout->horizontalSpacing();
     if (spacing < 0) {
         // same inter-column spacing for all rows, see comment in qformlayout.cpp
-        spacing = style()->combinedLayoutSpacing(QSizePolicy::Label, QSizePolicy::LineEdit, Qt::Horizontal, 0, this);
+        spacing = style()->combinedLayoutSpacing(QSizePolicy::Label, QSizePolicy::LineEdit, Qt::Horizontal, nullptr, this);
     }
 
     QLabel *c = new QLabel(comment, this);
@@ -335,8 +305,7 @@ QString KPasswordDialog::prompt() const
 
 void KPasswordDialog::setPassword(const QString &p)
 {
-    d->isToggleEchoModeAvailable = p.isEmpty();
-    d->ui.passEdit->setText(p);
+    d->ui.passEdit->setPassword(p);
 }
 
 void KPasswordDialog::setUsernameReadOnly(bool readOnly)
